@@ -13,7 +13,7 @@ Usage:
                         [--n-mads=5] [--min-dist=0] [--max-dist=auto]
                         [--no-plotting] [--min-separation=auto] [--dump=DIR]
                         [--threads=1] [--perc-zero=auto]
-                        [--perc-undetected=auto] <contact_map> [<output>]
+                        [--perc-undetected=auto] <contact_map> <prefix>
     chromosight generate-config [--preset loops] [--click contact_map]
                         [--force-norm] [--win-size=auto] [--n-mads=5]
                         [--threads=1] <prefix>
@@ -21,7 +21,7 @@ Usage:
                          [--win-fmt=json] [--kernel-config=FILE] [--force-norm]
                          [--threads=1] [--n-mads=5] [--win-size=auto]
                          [--perc-undetected=auto] [--perc-zero=auto]
-                         [--no-plotting] [--tsvd] <bed2d> <contact_map> <output>
+                         [--no-plotting] [--tsvd] <bed2d> <contact_map> <prefix>
     chromosight test
 
     detect:
@@ -44,7 +44,8 @@ Arguments for detect:
     --version                   Display the program's current version.
     contact_map                 The Hi-C contact map to detect patterns on, in
                                 bedgraph2d or cool format.
-    output                      name of the output directory
+    prefix                      Common path prefix used to generate output files.
+                                Extensions will be added for each file.
 
 Arguments for quantify:
     bed2d                       Tab-separated text files with columns chrom1, start1
@@ -52,7 +53,8 @@ Arguments for quantify:
                                 a pair of positions (i.e. a position in the matrix).
     contact_map                 Path to the contact map, in bedgraph2d or
                                 cool format.
-    output                      output directory where files should be generated.
+    prefix                      Common path prefix used to generate output files.
+                                Extensions will be added for each file.
 
 Arguments for generate-config:
     prefix                      Path prefix for config files. If prefix is a/b,
@@ -135,7 +137,6 @@ Advanced options:
 """
 import numpy as np
 import pandas as pd
-import pathlib
 import os
 import io
 from contextlib import contextmanager
@@ -204,7 +205,7 @@ def _override_kernel_config(param_name, param_value, param_type, config):
 def cmd_quantify(args):
     bed2d_path = args["<bed2d>"]
     mat_path = args["<contact_map>"]
-    output = pathlib.Path(args["<output>"])
+    prefix = args["<prefix>"]
     n_mads = float(args["--n-mads"])
     pattern = args["--pattern"]
     inter = args["--inter"]
@@ -223,9 +224,8 @@ def cmd_quantify(args):
     if win_size != "auto":
         win_size = int(win_size)
     subsample = args["--subsample"]
-    # Create directory if it does not exist
-    if not output.exists():
-        os.makedirs(output, exist_ok=True)
+    # If prefix involves a directory, crash if it does not exist
+    cio.check_prefix_dir(prefix)
     # Load 6 cols from 2D BED file and infer header
     bed2d = cio.load_bed2d(bed2d_path)
     # Warn user if --inter is disabled but list contains inter patterns
@@ -255,8 +255,10 @@ def cmd_quantify(args):
     max_diag = hic_genome.clr.shape[0] * hic_genome.clr.binsize
     cfg["max_dist"] = min(furthest, max_diag)
     cfg["min_dist"] = 0
-    cfg = _override_kernel_config('max_perc_zero', perc_zero, float, cfg)
-    cfg = _override_kernel_config('max_perc_undetected', perc_undetected, float, cfg)
+    cfg = _override_kernel_config("max_perc_zero", perc_zero, float, cfg)
+    cfg = _override_kernel_config(
+        "max_perc_undetected", perc_undetected, float, cfg
+    )
 
     # Notify contact map instance of changes in scanning distance
     hic_genome.kernel_config = cfg
@@ -271,8 +273,8 @@ def cmd_quantify(args):
     if win_size != "auto":
         if not win_size % 2:
             raise ValueError("--win-size must be odd")
-        for i, k in enumerate(cfg['kernels']):
-            cfg['kernels'][i] = resize_kernel(k, factor=win_size / km)
+        for i, k in enumerate(cfg["kernels"]):
+            cfg["kernels"][i] = resize_kernel(k, factor=win_size / km)
         km = kn = win_size
         # Update kernel config after resizing kernels
         hic_genome.kernel_config = cfg
@@ -384,29 +386,26 @@ def cmd_quantify(args):
             ],
         ]
         # Set p-values of invalid scores to nan
-        bed2d.loc[np.isnan(bed2d.score), 'pvalue'] = np.nan
-        bed2d.loc[np.isnan(bed2d.score), 'qvalue'] = np.nan
-        cio.write_patterns(bed2d, f"{pattern}_quant", output)
-        # bed2d.to_csv(
-        #    output / f"{pattern}_quant.txt", sep="\t", header=True, index=False
-        # )
-        cio.save_windows(
-            windows, f"{pattern}_quant", output_dir=output, format=win_fmt
-        )
+        bed2d.loc[np.isnan(bed2d.score), "pvalue"] = np.nan
+        bed2d.loc[np.isnan(bed2d.score), "qvalue"] = np.nan
+        cio.write_patterns(bed2d, prefix)
+        cio.save_windows(windows, prefix, fmt=win_fmt)
         # Generate pileup visualisations if requested
         if plotting_enabled:
             # Compute and plot pileup
-            pileup_fname = ("pileup_of_{n}_{pattern}").format(
+            pileup_title = ("pileup_of_{n}_{pattern}").format(
                 pattern=cfg["name"], n=windows.shape[0]
             )
             windows_pileup = cid.pileup_patterns(windows)
             # Symmetrize pileup for diagonal patterns
-            if not cfg['max_dist']:
+            if not cfg["max_dist"]:
                 # Replace nan below diag by 0
                 windows_pileup = np.nan_to_num(windows_pileup)
                 # Add transpose
-                windows_pileup += np.transpose(windows_pileup) - np.diag(np.diag(windows_pileup))
-            pileup_plot(windows_pileup, name=pileup_fname, output=output)
+                windows_pileup += np.transpose(windows_pileup) - np.diag(
+                    np.diag(windows_pileup)
+                )
+            pileup_plot(windows_pileup, prefix, name=pileup_title)
 
 
 def cmd_generate_config(args):
@@ -421,9 +420,8 @@ def cmd_generate_config(args):
 
     cfg = cio.load_kernel_config(pattern, False)
 
-    # If prefix involves a directory, create it
-    if os.path.dirname(prefix):
-        os.makedirs(os.path.dirname(prefix), exist_ok=True)
+    # If prefix involves a directory, crash if it does not exist
+    cio.check_prefix_dir(prefix)
 
     # If a specific window size if requested, resize all kernels
     if win_size != "auto":
@@ -513,7 +511,7 @@ def cmd_detect(args):
     min_dist = args["--min-dist"]
     min_separation = args["--min-separation"]
     n_mads = float(args["--n-mads"])
-    output = args["<output>"]
+    prefix = args["<prefix>"]
     pattern = args["--pattern"]
     pearson = args["--pearson"]
     perc_zero = args["--perc-zero"]
@@ -529,12 +527,9 @@ def cmd_detect(args):
     smooth_trend = args["--smooth-trend"]
     if smooth_trend is None:
         smooth_trend = False
-    # If output is not specified, use current directory
-    if not output:
-        output = pathlib.Path()
-    else:
-        output = pathlib.Path(output)
-    output.mkdir(exist_ok=True)
+
+    # If prefix involves a directory, crash if it does not exist
+    cio.check_prefix_dir(prefix)
 
     if win_fmt not in ["npy", "json"]:
         sys.stderr.write("Error: --win-fmt must be either json or npy.\n")
@@ -629,9 +624,7 @@ def cmd_detect(args):
             # Run in multiprocessing subprocesses
             if threads > 1:
                 pool = mp.Pool(threads)
-                dispatcher = pool.imap(
-                    _detect_sub_mat, sub_mat_data, 1
-                )
+                dispatcher = pool.imap(_detect_sub_mat, sub_mat_data, 1)
             else:
                 dispatcher = map(_detect_sub_mat, sub_mat_data)
             for s, result in enumerate(dispatcher):
@@ -749,38 +742,41 @@ def cmd_detect(args):
     ### 3: WRITE OUTPUT
     sys.stderr.write(f"{all_coords.shape[0]} patterns detected\n")
     # Save patterns and their coordinates in a tsv file
-    cio.write_patterns(all_coords, cfg["name"] + "_out", output)
+    cio.write_patterns(all_coords, prefix)
     # Save windows as an array in an npy file
-    cio.save_windows(all_windows, cfg["name"] + "_out", output, format=win_fmt)
+    cio.save_windows(all_windows, prefix, fmt=win_fmt)
 
     # Generate pileup visualisations if requested
     if plotting_enabled:
         # Compute and plot pileup
-        pileup_fname = ("pileup_of_{n}_{pattern}").format(
+        pileup_title = ("Pileup of {n} {pattern}").format(
             pattern=cfg["name"], n=all_windows.shape[0]
         )
         windows_pileup = cid.pileup_patterns(all_windows)
         # Symmetrize pileup for diagonal patterns
-        if not cfg['max_dist']:
+        if not cfg["max_dist"]:
             # Replace nan below diag by 0
             windows_pileup = np.nan_to_num(windows_pileup)
             # Add transpose
-            windows_pileup += np.transpose(windows_pileup) - np.diag(np.diag(windows_pileup))
-        pileup_plot(windows_pileup, name=pileup_fname, output=output)
+            windows_pileup += np.transpose(windows_pileup) - np.diag(
+                np.diag(windows_pileup)
+            )
+        pileup_plot(windows_pileup, prefix, name=pileup_title)
 
 
 def cmd_test(args):
 
     sys.stderr.write(f"Fetching test dataset at {URL_EXAMPLE_DATASET}...\n")
-    tmp = tempfile.NamedTemporaryFile(delete=False)
-    cio.download_file(URL_EXAMPLE_DATASET, tmp.name)
+    tmp_cool = tempfile.NamedTemporaryFile(delete=False)
+    cio.download_file(URL_EXAMPLE_DATASET, tmp_cool.name)
 
     sys.stderr.write(f"Running detection on test dataset...\n")
 
-    args["<contact_map>"] = tmp.name
+    args["<contact_map>"] = tmp_cool.name
+    args["<prefix>"] = 'chromosight_test'
     args["--no-plotting"] = True
     cmd_detect(args)
-    os.unlink(tmp.name)
+    os.unlink(tmp_cool.name)
 
 
 @contextmanager
